Added logic in moveHost() to retain the mac address while migrating the host from device to another
diff --git a/TestON/drivers/common/cli/emulator/mininetclidriver.py b/TestON/drivers/common/cli/emulator/mininetclidriver.py
index c2fe66e..52b1130 100644
--- a/TestON/drivers/common/cli/emulator/mininetclidriver.py
+++ b/TestON/drivers/common/cli/emulator/mininetclidriver.py
@@ -442,11 +442,16 @@
                 self.handle.sendline( cmd )
                 self.handle.expect( "mininet>" )
 
                 # Determine ipaddress of the host-oldSw interface
                 cmd = "px ipaddr = hintf.IP()"
                 print "cmd3= ", cmd
                 self.handle.sendline( cmd )
                 self.handle.expect( "mininet>" )
+
+                cmd = "px macaddr = hintf.MAC()"
+                print "cmd3= ", cmd
+                self.handle.sendline( cmd )
+                self.handle.expect( "mininet>" )
                 
                 # Detach interface between oldSw-host
                 cmd = "px " + oldSw + ".detach( sintf )"
@@ -478,16 +483,22 @@
                 print "cmd7 = ", cmd
                 self.handle.sendline( cmd )
                 self.handle.expect( "mininet>" )
+
+                # Set macaddress of the host-newSw interface
+                cmd = "px " + host + ".setMAC( mac = macaddr, intf = hintf)"
+                print "cmd8 = ", cmd
+                self.handle.sendline( cmd )
+                self.handle.expect( "mininet>" )
                 
                 cmd = "net"
-                print "cmd8 = ", cmd
+                print "cmd9 = ", cmd
                 self.handle.sendline( cmd )
                 self.handle.expect( "mininet>" )
                 print "output = ", self.handle.before
 
                 # Determine ipaddress of the host-newSw interface
-                cmd = "h1 ifconfig"
-                print "cmd9= ", cmd
+                cmd = host + " ifconfig"
+                print "cmd10= ", cmd
                 self.handle.sendline( cmd )
                 self.handle.expect( "mininet>" )
                 print "ifconfig o/p = ", self.handle.before
@@ -442,11 +442,16 @@
                 self.handle.expect( "mininet>" )
 
-                # Determine ipaddress of the host-oldSw interface
+                # Determine ip and mac address of the host-oldSw interface
                 cmd = "px ipaddr = hintf.IP()"
                 print "cmd3= ", cmd